@@ -1,3 +1,13 @@
+/*! \file
+Copyright (c) 2003, The Regents of the University of California, through
+Lawrence Berkeley National Laboratory (subject to receipt of any required 
+approvals from U.S. Dept. of Energy) 
+
+All rights reserved. 
+
+The source code is distributed under BSD license, see the file License.txt
+at the top-level directory.
+*/
 
 /*! @file 
  * \brief This example illustrates how to divide up the processes into subgroups
@@ -38,7 +48,7 @@
 
 int main(int argc, char *argv[])
 {
-    superlu_options_t options;
+    superlu_dist_options_t options;
     SuperLUStat_t stat;
     SuperMatrix A;
     ScalePermstruct_t ScalePermstruct;
@@ -185,7 +195,7 @@ int main(int argc, char *argv[])
             options.Fact = DOFACT;
             options.Equil = YES;
             options.ColPerm = METIS_AT_PLUS_A;
-            options.RowPerm = LargeDiag;
+            options.RowPerm = LargeDiag_MC64;
             options.ReplaceTinyPivot = YES;
             options.Trans = NOTRANS;
             options.IterRefine = DOUBLE;
@@ -291,7 +301,7 @@ int main(int argc, char *argv[])
             options.Fact = DOFACT;
             options.Equil = YES;
             options.ColPerm = MMD_AT_PLUS_A;
-            options.RowPerm = LargeDiag;
+            options.RowPerm = LargeDiag_MC64;
             options.ReplaceTinyPivot = YES;
             options.Trans = NOTRANS;
             options.IterRefine = DOUBLE;
