@@ -24,14 +24,14 @@ at the top-level directory.
 
 
 /* Variables external to this file */
-extern LU_stack_t stack;
+extern SuperLU_LU_stack_t stack;
 
 
 void *duser_malloc_dist(int_t bytes, int_t which_end)
 {
     void *buf;
     
-    if ( StackFull(bytes) ) return (NULL);
+    if ( SuperLU_StackFull(bytes) ) return (NULL);
 
     if ( which_end == HEAD ) {
 	buf = (char*) stack.array + stack.top1;
@@ -129,10 +129,13 @@ int_t dQuerySpace_dist(int_t n, LUstruct_t *LUstruct, gridinfo_t *grid,
     mem_usage->total += (float)(2 * k * iword);
 #else
     /*mem_usage->total += stat->current_buffer;*/
-    printf(".. dQuery_Space: peak_buffer %.2f (MB)\n", stat->peak_buffer * 1.0e-6);
     mem_usage->total += stat->peak_buffer;
-#endif
 
+#if ( PRNTlevel>=1 )
+    if (iam==0) printf(".. dQuerySpace: peak_buffer %.2f (MB)\n",
+                       stat->peak_buffer * 1.0e-6);
+#endif
+#endif
     return 0;
 } /* dQuerySpace_dist */
 
