@@ -12,7 +12,7 @@ at the top-level directory.
  * \brief Definitions which are precision-neutral
  *
  * <pre>
- * -- Distributed SuperLU routine (version 4.0) --
+ * -- Distributed SuperLU routine (version 5.4) --
  * Lawrence Berkeley National Lab, Univ. of California Berkeley.
  * November 1, 2007
  *
@@ -43,6 +43,12 @@ at the top-level directory.
 #include <limits.h>
 #include <string.h>
 
+/* Following is for vtune */
+#if 0
+#include <ittnotify.h>
+#define USE_VTUNE
+#endif
+
 /*************************************************************************
  * Constants
  **************************************************************************/
@@ -57,9 +63,11 @@ at the top-level directory.
  * Versions 4.x and earlier do not include a #define'd version numbers.
  */
 #define SUPERLU_DIST_MAJOR_VERSION     5
-#define SUPERLU_DIST_MINOR_VERSION     1
+#define SUPERLU_DIST_MINOR_VERSION     4
 #define SUPERLU_DIST_PATCH_VERSION     0
+#define SUPERLU_DIST_RELEASE_DATE      "June 1, 2018"
 
+#include "superlu_dist_config.h"
 /* Define my integer size int_t */
 #ifdef _CRAY
   typedef short int_t;
@@ -160,8 +168,8 @@ at the top-level directory.
 #define LkVAL    14
 #define LkkDIAG  15
     /* For triangular solves. */
-#define XK_H     2  /* The header preceeding each X block. */
-#define LSUM_H   2  /* The header preceeding each MOD block. */
+#define XK_H     2  /* The header preceding each X block. */
+#define LSUM_H   2  /* The header preceding each MOD block. */
 #define GSUM     20 
 #define Xk       21
 #define Yk       22
@@ -222,6 +230,18 @@ at the top-level directory.
 #define VT_TRACEOFF
 #endif
 
+/* Support Windows */
+#ifndef SUPERLU_DIST_EXPORT
+#if MSVC
+#ifdef SUPERLU_DIST_EXPORTS
+#define SUPERLU_DIST_EXPORT __declspec(dllexport)
+#else
+#define SUPERLU_DIST_EXPORT __declspec(dllimport)
+#endif /* SUPERLU_DIST_EXPORTS */
+#else
+#define SUPERLU_DIST_EXPORT
+#endif /* MSVC */
+#endif /* SUPERLU_DIST_EXPORT */
 
 /***********************************************************************
  * New data types
@@ -398,6 +418,26 @@ typedef struct {
     int_t  *perm_c;
 } ScalePermstruct_t;
 
+/*-- Data structure for redistribution of B and X --*/
+typedef struct {
+    int  *B_to_X_SendCnt;
+    int  *X_to_B_SendCnt;
+    int  *ptr_to_ibuf, *ptr_to_dbuf;
+
+    /* the following are needed in the hybrid solver PDSLin */	
+    int *X_to_B_iSendCnt;
+    int *X_to_B_vSendCnt;
+    int    *disp_ibuf;
+    int_t  *send_ibuf;
+    void   *send_dbuf;
+
+    int_t  x2b, b2x;
+    int_t  *send_ibuf2;
+    int_t  *recv_ibuf2;
+    void   *send_dbuf2;
+    void   *recv_dbuf2;
+} pxgstrs_comm_t;
+
 /* 
  *-- This contains the options used to control the solution process.
  *
@@ -658,6 +698,7 @@ extern void    superlu_free_dist (void*);
 extern int_t   *intMalloc_dist (int_t);
 extern int_t   *intCalloc_dist (int_t);
 extern int_t   mc64id_dist(int_t *);
+extern int     c2cpp_GetAWPM(SuperMatrix *, gridinfo_t *, ScalePermstruct_t *);
 extern void  arrive_at_ublock (int_t, int_t *, int_t *, int_t *,
 			       int_t *, int_t *, int_t, int_t, 
 			       int_t *, int_t *, int_t *, gridinfo_t *);
@@ -683,6 +724,7 @@ extern void  PStatFree(SuperLUStat_t *);
 extern void  PStatPrint(superlu_dist_options_t *, SuperLUStat_t *, gridinfo_t *);
 extern void  log_memory(long long, SuperLUStat_t *);
 extern void  print_memorylog(SuperLUStat_t *, char *);
+extern int   superlu_dist_GetVersionNumber(int *, int *, int *);
 
 /* Prototypes for parallel symbolic factorization */
 extern float symbfact_dist
