@@ -1,3 +1,13 @@
+/*! \file
+Copyright (c) 2003, The Regents of the University of California, through
+Lawrence Berkeley National Laboratory (subject to receipt of any required 
+approvals from U.S. Dept. of Energy) 
+
+All rights reserved. 
+
+The source code is distributed under BSD license, see the file License.txt
+at the top-level directory.
+*/
 /*! @file
  * \brief Performs a symbolic factorization
  *
@@ -70,7 +80,7 @@ static void  pruneL(const int_t, const int_t *, const int_t, const int_t,
 int_t symbfact
 /************************************************************************/
 (
- superlu_options_t *options, /* input options */
+ superlu_dist_options_t *options, /* input options */
  int         pnum,     /* process number */
  SuperMatrix *A,       /* original matrix A permuted by columns (input) */
  int_t       *perm_c,  /* column permutation vector (input) */
@@ -173,10 +183,10 @@ int_t symbfact
 
     if ( !pnum && (options->PrintStat == YES)) {
 	nnzLU = nnzL + nnzU - min_mn;
-	printf("\tNonzeros in L       %ld\n", nnzL);
-	printf("\tNonzeros in U       %ld\n", nnzU);
-	printf("\tnonzeros in L+U     %ld\n", nnzLU);
-	printf("\tnonzeros in LSUB    %ld\n", nnzLSUB);
+	printf("\tNonzeros in L       %lld\n", nnzL);
+	printf("\tNonzeros in U       %lld\n", nnzU);
+	printf("\tnonzeros in L+U     %lld\n", nnzLU);
+	printf("\tnonzeros in LSUB    %lld\n", nnzLSUB);
     }
     SUPERLU_FREE(iwork);
 
@@ -316,9 +326,9 @@ static int_t snode_dfs
 		marker[krow] = kcol;
 		lsub[nextl++] = krow;
 		if ( nextl >= nzlmax ) {
-		    if (mem_error = symbfact_SubXpand(A->ncol, jcol, nextl,
+		    if ((mem_error = symbfact_SubXpand(A->ncol, jcol, nextl,
 						      (MemType) LSUB, &nzlmax,
-						      Glu_freeable))
+						       Glu_freeable)))
 			return (mem_error);
 		    lsub = Glu_freeable->lsub;
 		}
@@ -332,8 +342,8 @@ static int_t snode_dfs
     if ( jcol < kcol ) {
 	new_next = nextl + (nextl - xlsub[jcol]);
 	while ( new_next > nzlmax ) {
-	    if (mem_error = symbfact_SubXpand(A->ncol, jcol, nextl, (MemType) LSUB,
-					      &nzlmax, Glu_freeable))
+	    if ((mem_error = symbfact_SubXpand(A->ncol, jcol, nextl, (MemType) LSUB,
+					       &nzlmax, Glu_freeable)))
 		return (mem_error);
 	    lsub = Glu_freeable->lsub;
 	}
